@@ -34,7 +34,7 @@ def loop_pattern_func(f):
         for i in range(LCM(*[len(arg) for arg in args if (hasattr(arg, '__len__') and not isinstance(arg, PGroup))])):
             pat |= f(*[(arg[i] if isinstance(arg, Pattern) else arg) for arg in args])
         return pat
-    new_function.argspec = inspect.getargspec(f)
+    new_function.argspec = inspect.getfullargspec(f)
     return new_function
 
 # TODO -- if it isn't looped, return the original if it is a group
@@ -58,7 +58,7 @@ def loop_pattern_method(f):
             pat |= f(self, *[(modi(arg, i) if not isinstance(arg, PGroup) else arg) for arg in args])
         return pat
 
-    new_function.argspec = inspect.getargspec(f)
+    new_function.argspec = inspect.getfullargspec(f)
     return new_function
 
 def PatternMethod(f):
@@ -912,7 +912,7 @@ class metaPattern(object):
         new = Pattern()
         if isinstance(data, Pattern):
             new.data = self.data + data.data
-        elif isinstance(data, (list, str)):
+        elif isinstance(data, (list, str, range)):
             new.data = list(self.data)
             new.data.extend(map(convert_nested_data, data))
         else:
@@ -1013,7 +1013,7 @@ class metaPattern(object):
         """ This method automatically laces and groups the data """
 
         #: Force data into an iterable form
-        if isinstance(self.data, str):
+        if isinstance(self.data, (str, range)):
 
             self.data = list(self.data)
             
@@ -1129,7 +1129,7 @@ class PGroup(metaPattern):
             args = list(self.data)
             args.append(data)
             new = PGroup(*args)
-        elif isinstance(data, (list, str)):
+        elif isinstance(data, (list, str, range)):
             new.data = list(self.data)
             new.data.extend(map(convert_nested_data, data))
         else:
