@@ -765,11 +765,11 @@ class Queue(object):
 
         try:
 
-            function = inspect.getargspec(item)
+            function = inspect.getfullargspec(item)
 
         except TypeError:
 
-            function = inspect.getargspec(item.__call__)
+            function = inspect.getfullargspec(item.__call__)
 
         # If the item can't take arbitrary keywords, check any kwargs are valid
 
